# Verocase concepts


## References

Argevede-LTAC, "Lightweight Text Assurance Case (LTAC)" <https://www.argevide.com/lightweight-text-assurance-case-ltac/>

Argevede-Textual, "Textual vs graphical representation of assurance cases", 2023-06-30 <https://www.argevide.com/textual-vs-graphical-representation-of-assurance-cases/>

Odu, Oluwafemi, et al, 2024-10-07, "Automatic Instantiation of Assurance Cases from Patterns Using Large Language Models". <https://arxiv.org/abs/2410.05488v1>

Holloway, C.M., SAFETY CASE NOTATIONS: ALTERNATIVES FOR THE NON-GRAPHICALLY INCLINED? <https://ntrs.nasa.gov/api/citations/20080042416/downloads/20080042416.pdf>

Goal Structuring Notation (GSN) Standard Home <https://scsc.uk/gsn-standard>

Goal Structuring Notation (GSN) standard (version 3) <https://scsc.uk/scsc-141c>
